cloud-infra: Set the provisioner type

Heat is now supported in addition to bifrost so the determination
of the provisioner and the temporary SDF are updated accordingly.

Change-Id: I01a48c5f54d2386fca8c3c90fe38daccd1d7dfd4
diff --git a/jjb/cloud-infra/prepare-for-scenario-deploy.sh b/jjb/cloud-infra/prepare-for-scenario-deploy.sh
index 9729dd8..0b469c3 100644
--- a/jjb/cloud-infra/prepare-for-scenario-deploy.sh
+++ b/jjb/cloud-infra/prepare-for-scenario-deploy.sh
@@ -33,6 +33,8 @@
     src: $PROJECT_GIT_URL
     version: $GERRIT_PATCHSET_REVISION
     refspec: $GERRIT_REFSPEC
+    provisioners:
+      - $PROVISIONER_TYPE
     installers:
       $INSTALLER_TYPE:
         role: scenarios/$DEPLOY_SCENARIO/$INSTALLER_TYPE/role/$DEPLOY_SCENARIO
diff --git a/jjb/cloud-infra/prepare-for-scenario-test.sh b/jjb/cloud-infra/prepare-for-scenario-test.sh
index b1f42f0..c45b787 100644
--- a/jjb/cloud-infra/prepare-for-scenario-test.sh
+++ b/jjb/cloud-infra/prepare-for-scenario-test.sh
@@ -33,6 +33,8 @@
     src: $PROJECT_GIT_URL
     version: $GERRIT_PATCHSET_REVISION
     refspec: $GERRIT_REFSPEC
+    provisioners:
+      - $PROVISIONER_TYPE
     installers:
       $INSTALLER_TYPE:
         role: scenarios/$DEPLOY_SCENARIO/$INSTALLER_TYPE/role/$DEPLOY_SCENARIO
diff --git a/jjb/cloud-infra/determine-scenario.sh b/jjb/cloud-infra/determine-scenario.sh
index fffe5c9..77d6c9b 100644
--- a/jjb/cloud-infra/determine-scenario.sh
+++ b/jjb/cloud-infra/determine-scenario.sh
@@ -25,21 +25,31 @@
 # this function processes commit message to determine the impacted scenario
 # using the input provided by the committer.
 #
 # installer type and scenario should be placed at the beginning of lines
 # separately and the format of the entry in commit message is as below
 #
+# provisioner-type: <provisioner type>
 # installer-type: <installer type>
 # deploy-scenario: <scenario name>
 #
 # example is
 #
+# provisioner-type: bifrost
 # installer-type: kubespray
 # deploy-scenario: k8-calico-nofeature
 function override_installer_scenario() {
-  echo "Info: Processing $GERRIT_PROJECT patchset $GERRIT_REFSPEC to determine the installer and the scenario"
+  echo "Info: Processing $GERRIT_PROJECT patchset $GERRIT_REFSPEC to determine the provisioner, installer and, scenario"
   cd $WORKSPACE
   COMMIT_MESSAGE=$(git show -s --format=%B)
 
+  if [[ "$COMMIT_MESSAGE" =~ "provisioner-type:" ]]; then
+    # we support heat as well so ensure we capture it
+    export PROVISIONER_TYPE=$(echo "$COMMIT_MESSAGE" | grep '^provisioner-type:' | cut -d":" -f2 | sed 's/\s*//g')
+  else
+    # default is almost always bifrost
+    export PROVISIONER_TYPE=bifrost
+  fi
+
   if [[ "$COMMIT_MESSAGE" =~ "deploy-scenario:" && "$COMMIT_MESSAGE" =~ "installer-type:" ]]; then
     export INSTALLER_TYPE=$(echo "$COMMIT_MESSAGE" | grep '^installer-type:' | cut -d":" -f2 | sed 's/\s*//g')
     export DEPLOY_SCENARIO=$(echo "$COMMIT_MESSAGE" | grep '^deploy-scenario:' | cut -d":" -f2 | sed 's/\s*//g')
@@ -59,6 +69,7 @@
   echo "Info: Processing $GERRIT_PROJECT patchset $GERRIT_REFSPEC"
   if [[ "$GERRIT_PROJECT" == "infra/engine" ]]; then
     echo "Info: Setting INSTALLER_TYPE and DEPLOY_SCENARIO to defaults for project $GERRIT_PROJECT patchset $GERRIT_REFSPEC"
+    export PROVISIONER_TYPE=bifrost
     export INSTALLER_TYPE=kubespray
     export DEPLOY_SCENARIO=k8-calico-nofeature
     write_change_metadata
@@ -74,6 +85,7 @@
   echo "Info: Writing change metadata to $WORKSPACE/change.properties"
   cat << EOF > $WORKSPACE/change.properties
 PROJECT_GIT_URL=$GIT_BASE_HTTPS/$GERRIT_PROJECT
+PROVISIONER_TYPE=$PROVISIONER_TYPE
 INSTALLER_TYPE=$INSTALLER_TYPE
 DEPLOY_SCENARIO=$DEPLOY_SCENARIO
 GERRIT_PATCHSET_REVISION=$GERRIT_PATCHSET_REVISION
@@ -89,8 +101,9 @@
   exit 0
 }
 
-echo "Info: Determining the impacted scenario and used installer"
+echo "Info: Determining the provisioner, installer, and scenario"
 
+declare -a PROVISIONER_TYPE
 declare -a INSTALLER_TYPE
 declare -a DEPLOY_SCENARIO
 
@@ -25,21 +25,31 @@
 # using the input provided by the committer.
 #
-# installer type and scenario should be placed at the beginning of lines
-# separately and the format of the entry in commit message is as below
+# provisioner type, installer type and scenario should be placed at the beginning of
+# lines separately and the format of the entry in commit message is as below
 #